.. _example-name:

!!!!!!!
example
!!!!!!!

.. meta::
   :keywords: example, examples

.. index:: example, examples

.. _example-title:

Examples
########

.. csv-table::
   :header:  "Name", "Title"
   :widths: auto

   "get_started", :ref:`get_started-title`
   "literal_example", :ref:`literal_example-title`
   "dir_example", :ref:`dir_example-title`
   "toc_list_example", :ref:`toc_list_example-title`
   "spell_example", :ref:`spell_example-title`
   "suspend_example", :ref:`suspend_example-title`
   "code_example", :ref:`code_example-title`
   "comment_example", :ref:`comment_example-title`
   "comment_ch_example", :ref:`comment_ch_example-title`
   "heading_example", :ref:`heading_example-title`
   "indent_example", :ref:`indent_example-title`
   "docstring_example", :ref:`docstring_example-title`
   "configure_example", :ref:`configure_example-title`
   ".readthedocs.yaml", :ref:`.readthedocs.yaml-title`
   "testExample", :ref:`testExample-title`

.. toctree::
   :maxdepth: 1
   :hidden:

   get_started
   literal_example
   dir_example
   toc_list_example
   spell_example
   suspend_example
   code_example
   comment_example
   comment_ch_example
   heading_example
   indent_example
   docstring_example
   configure_example
   .readthedocs.yaml
   testExample
